@@ -37,8 +37,8 @@ sub probe ($$) {
     my ($self, $obj) = @_;
 
     if ($self->{-ctx}->{-platform}->id() =~ m/FreeBSD/i) {
-        my $hwCpuNum   = undef;
-        my @hwCpuENTRY = undef; #N/A
+        my $hwCpuNum;
+        my @hwCpuENTRY; #N/A
 
         #   local workspace
         my $out; my $raw;
@@ -53,8 +53,8 @@ sub probe ($$) {
         $obj->{-value} = $hwCpuNum if ($obj->{-name} =~ m/\.hwCpuNum$/);
     }
     elsif ($self->{-ctx}->{-platform}->id() =~ m/Linux/i) {
-        my $hwCpuNum   = undef;
-        my @hwCpuENTRY = undef; #N/A
+        my $hwCpuNum;
+        my @hwCpuENTRY; #N/A
 
         #   local workspace
         my $out; my $raw;
@@ -71,8 +71,8 @@ sub probe ($$) {
         $obj->{-value} = $hwCpuNum if ($obj->{-name} =~ m/\.hwCpuNum$/);
     }
     elsif($self->{-ctx}->{-platform}->id() =~ m/SunOS/i) {
-        my $hwCpuNum   = undef;
-        my @hwCpuENTRY = undef;
+        my $hwCpuNum;
+        my @hwCpuENTRY;
 
         #   local workspace
         my $out; my $raw; my $arch;
