@@ -37,13 +37,13 @@ sub probe ($$) {
     my ($self, $obj) = @_;
 
     if ($self->{-ctx}->{-platform}->id() =~ m/FreeBSD/i) {
-        my @hwDiskENTRY = undef; #N/A
+        my @hwDiskENTRY; #N/A
     }
     elsif ($self->{-ctx}->{-platform}->id() =~ m/Linux/i) {
-        my @hwDiskENTRY = undef; #N/A
+        my @hwDiskENTRY; #N/A
     }
     elsif($self->{-ctx}->{-platform}->id() =~ m/SunOS/i) {
-        my @hwDiskENTRY = undef;
+        my @hwDiskENTRY;
         my $n = 0;
 
         #   local workspace
