@@ -37,13 +37,13 @@ sub probe ($$) {
     my ($self, $obj) = @_;
 
     if ($self->{-ctx}->{-platform}->id() =~ m/FreeBSD/i) {
-        my @hwFanENTRY = undef; #N/A
+        my @hwFanENTRY; #N/A
     }
     elsif ($self->{-ctx}->{-platform}->id() =~ m/Linux/i) {
-        my @hwFanENTRY = undef; #N/A
+        my @hwFanENTRY; #N/A
     }
     elsif($self->{-ctx}->{-platform}->id() =~ m/SunOS/i) {
-        my @hwFanENTRY = undef;
+        my @hwFanENTRY;
         my $n = 0;
 
         #   local workspace
