@@ -37,7 +37,7 @@ sub probe ($$) {
     my ($self, $obj) = @_;
 
     if ($self->{-ctx}->{-platform}->id() =~ m/FreeBSD/i) {
-    	my @sysFsENTRY  = undef;
+    	my @sysFsENTRY;
         my $n = 0;
         
         #   local workspace
@@ -82,7 +82,7 @@ sub probe ($$) {
         }
     }
     elsif ($self->{-ctx}->{-platform}->id() =~ m/Linux/i) {
-    	my @sysFsENTRY  = undef;
+    	my @sysFsENTRY;
         my $n = 0;
         
         #   local workspace
@@ -127,7 +127,7 @@ sub probe ($$) {
         }
     }
     elsif($self->{-ctx}->{-platform}->id() =~ m/SunOS/i) {
-    	my @sysFsENTRY  = undef;
+    	my @sysFsENTRY;
         my $n = 0;
         
         #   local workspace
