@@ -150,7 +150,7 @@ sub store ($$$$) {
 sub fetch ($$) {
     my ($self, $id) = @_;
 
-    my $value = undef;
+    my $value;
     if (defined($self->{-cache}->{$id})) {
         if ($self->{-cache}->{$id}->{-expires} > time()) {
             $value = $self->{-cache}->{$id}->{-value};
@@ -724,13 +724,17 @@ while (1) {
 
         #  re-entry point for OID processing
         my $oid_search = $oid_request;
+        my $oid_action;
+        my $oid_handled;
+        my $oid_handler;
+        my $oid_next;
         RETRY:
 
         #   determine acted/handled OID
-        my $oid_action  = undef;
-        my $oid_handled = undef;
-        my $oid_handler = undef;
-        my $oid_next    = undef;
+        $oid_action  = undef;
+        $oid_handled = undef;
+        $oid_handler = undef;
+        $oid_next    = undef;
         if ($cmd =~ m/^GET$/i) {
             #   search for explicitly handled OID
             for (my $i = 0; defined($oidtable->[$i]); $i++) {
